/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.artifact;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.Reader;
import java.io.UnsupportedEncodingException;

import org.n52.security.common.util.StringInputStream;

public class TextualPayload implements Payload {
    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(TextualPayload.class);

    private String m_payload = "";

    private String m_streamCharset;

    public TextualPayload(final InputStream pInputStream, final String pCharsetName) throws IOException {
        m_streamCharset = pCharsetName;
        init(new InputStreamReader(pInputStream, pCharsetName));
    }

    public TextualPayload(final String pContent, final String pStreamCharset) {
        m_payload = pContent;
        m_streamCharset = pStreamCharset;
    }

    private void init(final Reader pReader) throws IOException {
        StringBuffer lBuffer = new StringBuffer(4096);
        char[] buffer = new char[4096];

        try {
            int readChars;
            while ((readChars = pReader.read(buffer)) != -1) {
                lBuffer.append(buffer, 0, readChars);
            }

        } finally {
            pReader.close();
        }
        if (lBuffer.length() > 0) {
            m_payload = lBuffer.toString();
        }
    }

    public InputStream getAsStream() {
        try {
            return new StringInputStream(m_payload,
                    (m_streamCharset != null && !m_streamCharset.equals("")) ? m_streamCharset : "UTF-8");
        } catch (UnsupportedEncodingException e) {
            LOG.error("Cannot encode as stream", e);
            return new ByteArrayInputStream(m_payload.getBytes());
        }
    }

    public String toString() {
        return m_payload;
    }

}
