/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 05.08.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.attributes;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * Utility class wich shall encapsulate simple methods
 * for easier life with attribute processing.
 *
 * @author Marko Reiprecht
 *         Created on 05.08.2008
 * @version $Revision: $
 */
public final class AttributeUtil {

    private AttributeUtil() {}

    /**
     * Converts a collection of Attributes to a Map.
     *
     * @param attributes a collection of Attributes
     * @return a Map with the Attributes indexed by their keys.
     * @throws IllegalArgumentException if an object in attributes is not a subclass of Attribute.
     */
    public static Map<String, Attribute> fillAttributeMap(final Collection<Attribute> attributes) throws IllegalArgumentException {
        return fillAttributeMap(null, attributes);
    }

    /**
     * Converts a collection of Attributes to a Map.
     *
     * @param out        the outcomming map, if null a new map is constructed.
     * @param attributes a collection of Attributes
     * @return a Map with the Attributes indexed by their keys.
     * @throws IllegalArgumentException if an object in attributes is not a subclass of Attribute.
     */
    public static Map<String, Attribute> fillAttributeMap(final Map<String, Attribute> out, final Collection<Attribute> attributes) throws IllegalArgumentException {
        try {
            Map<String, Attribute> attrmap = out != null ? out : new HashMap<String, Attribute>(attributes.size(), 0.9f);

            for (Attribute attribute : attributes) {
                attrmap.put(attribute.getKey(), attribute);
            }
            return attrmap;
        } catch (ClassCastException ex) {
            throw new IllegalArgumentException(
                    "only subclasses of <" + Attribute.class.getName() + "> allowed. " + ex);
        }
    }
}
