/*******************************************************************************
 * Copyright (C) 2009
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 ******************************************************************************/

package org.n52.security.common.ip;

import java.net.InetAddress;
import java.util.Comparator;

/**
 * This comparator allows to compare two IP addresses.
 *
 * @author jdr
 *
 */
public class InetAddressComparator implements Comparator {

    /**
     * Compares two IP4Addresses.
     * The addresses are compared by component (each of them seperated by a period), starting with the highest
     * component. An address is greater than another if the first component found that differs is greater.
     *
     * <li> <code>123.0.0.1 > 122.255.255.255</code>
     *
     * <li> <code>123.0.1.1 > 123.0.1.0</code>
     *
     * <li> <code>123.0.0.001 == 123.0.0.1</code>
     *
     * @param arg0
     *            the first address.
     * @param arg1
     *            the second address.
     */
    public int compare(Object arg0, Object arg1) {

        if (!(arg0 instanceof InetAddress) || !(arg1 instanceof InetAddress)) {
            throw new IllegalArgumentException("Object must be of type " + InetAddress.class);
        }

        InetAddress theFirst = (InetAddress) arg0;
        InetAddress theSecond = (InetAddress) arg1;

        byte[] firstBytes = theFirst.getAddress();
        byte[] secondBytes = theSecond.getAddress();

        for (int i = 0; i < firstBytes.length; i++) {
            int delta = (firstBytes[i] & 0xff) - (secondBytes[i] & 0xff);
            if (delta != 0)
                return delta;
        }
        return 0;
    }

}
