/**
 * *****************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 23.03.2008
 *****************************************************************************
 */
package org.n52.security.common.xml;

import java.io.InputStream;
import java.io.Reader;
import java.io.StringReader;

import org.w3c.dom.ls.LSInput;
import org.xml.sax.InputSource;

/**
 * Adapts the LSInput interface to the 'old' InputSource interface.
 * <p/>
 */
public class LSInputSourceAdapter implements LSInput {

    private InputSource m_inputSource;
    private String m_baseUri;
    private boolean m_certifiedText;

    public LSInputSourceAdapter(final InputSource inputSource) {
        this(inputSource, null);
    }

    public LSInputSourceAdapter(final InputSource inputSource, final String baseUri) {
        this(inputSource, baseUri, false);
    }

    public LSInputSourceAdapter(final InputSource inputSource, final String baseUri, final boolean certifiedText) {
        if (inputSource == null) {
            throw new IllegalArgumentException("inputSource must not null");
        }
        m_inputSource = inputSource;
        m_baseUri = baseUri;
        m_certifiedText = certifiedText;
    }

    @Override
    public String getBaseURI() {
        return m_baseUri;
    }

    @Override
    public void setBaseURI(final String baseURI) {
        m_baseUri = baseURI;
    }

    @Override
    public InputStream getByteStream() {
        return m_inputSource.getByteStream();
    }

    @Override
    public void setByteStream(final InputStream byteStream) {
        m_inputSource.setByteStream(byteStream);
    }

    @Override
    public boolean getCertifiedText() {
        return m_certifiedText;
    }

    @Override
    public void setCertifiedText(final boolean certifiedText) {
        m_certifiedText = certifiedText;
    }

    @Override
    public Reader getCharacterStream() {
        return m_inputSource.getCharacterStream();
    }

    @Override
    public void setCharacterStream(final Reader characterStream) {
        m_inputSource.setCharacterStream(characterStream);
    }

    @Override
    public String getEncoding() {
        return m_inputSource.getEncoding();
    }

    @Override
    public void setEncoding(final String encoding) {
        m_inputSource.setEncoding(encoding);
    }

    @Override
    public String getPublicId() {
        return m_inputSource.getPublicId();
    }

    @Override
    public void setPublicId(final String publicId) {
        m_inputSource.setPublicId(publicId);
    }

    @Override
    public String getStringData() {
        return null;
    }

    @Override
    public void setStringData(final String stringData) {
        m_inputSource.setCharacterStream(new StringReader(stringData));
    }

    @Override
    public String getSystemId() {
        return m_inputSource.getSystemId();
    }

    @Override
    public void setSystemId(final String systemId) {
        m_inputSource.setSystemId(systemId);
    }
}
