/*******************************************************************************
 * Copyright (C) 2008
 * by 52 North Initiative for Geospatial Open Source Software GmbH
 *
 * Contact: Andreas Wytzisk
 * 52 North Initiative for Geospatial Open Source Software GmbH
 * Martin-Luther-King-Weg 24
 * 48155 Muenster, Germany
 * info@52north.org
 *
 * This program is free software; you can redistribute and/or modify it under
 * the terms of the GNU General Public License version 2 as published by the
 * Free Software Foundation.
 *
 * This program is distributed WITHOUT ANY WARRANTY; even without the implied
 * WARRANTY OF MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program (see gnu-gpl v2.txt). If not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA or
 * visit the Free Software Foundation web page, http://www.fsf.org.
 *
 * Author: Marko Reiprecht
 * Created: 26.08.2008
 * Modified: $Date $
 ******************************************************************************/
/* $Id: $ */
package org.n52.security.common.xml;

import java.util.LinkedList;

import javax.xml.XMLConstants;

import org.w3c.dom.Document;
import org.w3c.dom.Element;

/**
 * Removes prefixes from the a DOM tree.
 *
 * @author Marko Reiprecht
 *         Created on 26.08.2008
 * @version $Revision: $
 */
public class XMLPrefixRemover {

    public Document removePrefixes(final Document document) {
        removePrefixes(document.getDocumentElement());
        return document;
    }

    /**
     * Removes all prefixes from the given XML and change it to the default namespaces.
     *
     */
    public Element removePrefixes(final Element node) {
        new DocumentTraverser().traverseDepthFirst(node, new DocumentVisitorAdapter() {
            private LinkedList<String> m_currentNamespaceStack = new LinkedList<String>();

            public void preVisit(final Element element) {
                String currentNamespace =
                        m_currentNamespaceStack.isEmpty() ? null : (String) m_currentNamespaceStack.getFirst();
                if (currentNamespace == null || !currentNamespace.equals(element.getNamespaceURI())) {
                    currentNamespace = element.getNamespaceURI();
                    element.setAttribute(XMLConstants.XMLNS_ATTRIBUTE, currentNamespace);
                }
                element.setPrefix(XMLConstants.DEFAULT_NS_PREFIX);
                m_currentNamespaceStack.addFirst(currentNamespace);
            }

            public void postVisit(final Element element) {
                m_currentNamespaceStack.removeFirst();
            }
        });
        return node;
    }
}
